<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ie">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Pri</translation>
    </message>
    <message>
        <location filename="../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>Minimalistic gerente de files</translation>
    </message>
    <message>
        <location filename="../about.ui" line="122"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programmation:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="144"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.ui" line="113"/>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt&quot;&gt;https://github.com/lxqt/pcmanfm-qt&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="74"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Wiki: &lt;a href=&quot;https://github.com/lxqt/pcmanfm-qt/wiki&quot;&gt;https://github.com/lxqt/pcmanfm-qt/wiki&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="135"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>Tip del medie:</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>Detectente...</translation>
    </message>
    <message>
        <location filename="../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BulkRenameDialog</name>
    <message>
        <location filename="../bulk-rename.ui" line="6"/>
        <source>Bulk Rename</source>
        <translation>Renomination in masse</translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="12"/>
        <source>Serial Renaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="36"/>
        <source># will be replaced by numbers starting with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="68"/>
        <source>Pad numbers with zero if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="75"/>
        <source>Use localized numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="85"/>
        <source>Replacement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="97"/>
        <source>Find in names:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="107"/>
        <source>Replace with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="117"/>
        <source>Case-sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="124"/>
        <source>Regular expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="134"/>
        <source>Change Case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="146"/>
        <source>To upper case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="156"/>
        <source>To lower case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulk-rename.ui" line="27"/>
        <source>Name#</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation>Conexer a un lontan servitor</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="80"/>
        <source>Anonymous &amp;login</source>
        <translation>An&amp;onim</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="90"/>
        <source>Login as &amp;user:</source>
        <translation>Quam un &amp;usator:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="29"/>
        <source>Specify remote folder to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../connect.ui" line="36"/>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="56"/>
        <source>Port:</source>
        <translation>Portu:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="70"/>
        <source>Path:</source>
        <translation>Rute:</translation>
    </message>
    <message>
        <location filename="../connect.ui" line="46"/>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
</context>
<context>
    <name>DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.ui" line="14"/>
        <source>Create Launcher</source>
        <translation>Crear un lansator</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="38"/>
        <source>Name:</source>
        <translation>Nómine:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="45"/>
        <source>Specific name of this launcher.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="58"/>
        <source>Description:</source>
        <translation>Descrition:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="65"/>
        <source>A short description or generic name, like &quot;Web Browser&quot; or &quot;Home Directory&quot;.

It can be left empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="77"/>
        <source>Comment:</source>
        <translation>Comenta:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="84"/>
        <source>A short comment.

It can be left empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="117"/>
        <source>Command:</source>
        <translation>Comande:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="133"/>
        <location filename="../desktopentrydialog.ui" line="164"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="142"/>
        <source>Icon:</source>
        <translation>Icone:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="151"/>
        <source>Icon to display in file manager, menus, etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="173"/>
        <location filename="../desktopentrydialog.ui" line="183"/>
        <source>Run in terminal?</source>
        <translation>Lansar in li terminal?</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="176"/>
        <source>Terminal:</source>
        <translation>Terminal:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="186"/>
        <source>Whether the launched program should run in a terminal window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="190"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="195"/>
        <source>Yes</source>
        <translation>Yes</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="203"/>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="210"/>
        <source>Whether this is a link or executes a command.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="214"/>
        <source>Application</source>
        <translation>Application</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="219"/>
        <source>Link</source>
        <translation>Ligament</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="96"/>
        <source>Categories:</source>
        <translation>Categories:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.ui" line="103"/>
        <source>Semicolon separated categories in which the entry should be shown if it is used by the DE&apos;s main menu (e.g., when put inside ~/.local/share/applications).

It is needed only when you want to use the created file in the main menu. Otherwise, you could leave it empty.

Examples: AudioVideo, Audio, Video, Development, Education, Game, Graphics, Network, Office, Settings, System, Utility, Qt.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>Pupitre</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>Fólder del Pupitre:</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>File de image</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>Rute de fólder</translation>
    </message>
    <message>
        <location filename="../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>&amp;Trovar</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>Preferenties del Pupitre</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="338"/>
        <location filename="../desktop-preferences.ui" line="344"/>
        <source>Background</source>
        <translation>Funde</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="385"/>
        <source>Wallpaper mode:</source>
        <translation>Mode del tapete:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="408"/>
        <source>Wallpaper image file:</source>
        <translation>File del tapete:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="350"/>
        <source>Select background color:</source>
        <translation>Selecter un color del funde:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="417"/>
        <source>Image file</source>
        <translation>File de image</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="423"/>
        <source>Image file path</source>
        <translation>Rute del file</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="430"/>
        <source>&amp;Browse</source>
        <translation>&amp;Trovar</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="30"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="36"/>
        <source>Icon size:</source>
        <translation>Dimension de icones:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="49"/>
        <source>Label Text</source>
        <translation>Etiquette</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="113"/>
        <source>Select shadow color:</source>
        <translation>Selecter un color de ombre:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="61"/>
        <source>Select font:</source>
        <translation>Selecter un fonde:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="87"/>
        <source>Select text color:</source>
        <translation>Selecter un color de textu:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="136"/>
        <source>Spacing</source>
        <translation>Interspacie</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="145"/>
        <source>Minimum item margins:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="152"/>
        <source>3 px by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="155"/>
        <location filename="../desktop-preferences.ui" line="179"/>
        <location filename="../desktop-preferences.ui" line="237"/>
        <location filename="../desktop-preferences.ui" line="249"/>
        <location filename="../desktop-preferences.ui" line="275"/>
        <location filename="../desktop-preferences.ui" line="287"/>
        <source> px</source>
        <translation> pix</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="168"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="175"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="192"/>
        <source>Lock</source>
        <translation>Serrar</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="230"/>
        <source>Margins of work area:</source>
        <translation>Márgines de labor-region:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="303"/>
        <source>By default, desktop folders will be opened in PCManFM-Qt if they
are left clicked, even when it is not the default file manager.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="307"/>
        <source>Open desktop folders in default file manager by left clicking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="314"/>
        <source>Make all items stick to their positions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="373"/>
        <source>Wallpaper</source>
        <translation>Tapete</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="439"/>
        <source>Transform image based on EXIF data</source>
        <translation>Rotar images secun li data EXIF</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="446"/>
        <source>Individual wallpaper for each monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="473"/>
        <source>Slide Show</source>
        <translation>Exhibition</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="479"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="491"/>
        <source>Wallpaper image folder:</source>
        <translation>Fólder de tapetes:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="505"/>
        <source>Browse</source>
        <translation>Trovar</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="512"/>
        <source> hour(s)</source>
        <translation> hor(es)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="522"/>
        <source>and</source>
        <translation>e</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="535"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="538"/>
        <source>Interval:</source>
        <translation>Intervalle:</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="545"/>
        <source> minute(s)</source>
        <translation> minute(s)</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="498"/>
        <source>Wallpaper folder</source>
        <translation>Fólder de tapetes</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="587"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="620"/>
        <source>Visible Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="626"/>
        <source>Home</source>
        <translation>Hem</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="637"/>
        <source>Trash</source>
        <translation>Paper-corb</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="648"/>
        <source>Computer</source>
        <translation>Computator</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="659"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../desktop-preferences.ui" line="614"/>
        <source>Advanced</source>
        <translation>Avansat</translation>
    </message>
</context>
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="21"/>
        <source>Shortcut</source>
        <translation>Rapid-taste</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="26"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="31"/>
        <source>Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Focus view, clear filter bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Ctrl+Esc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="42"/>
        <source>Focus side-pane</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="50"/>
        <location filename="../shortcuts.ui" line="58"/>
        <source>Focus path entry</source>
        <translation>Focar li camp de rute</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <source>Alt+D</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Ctrl+Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="66"/>
        <location filename="../shortcuts.ui" line="82"/>
        <source>Next tab</source>
        <translation>Sequent carte</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Ctrl+Shift+Tab</source>
        <translation>Ctrl+Shift+Tab</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="74"/>
        <location filename="../shortcuts.ui" line="90"/>
        <source>Previous tab</source>
        <translation>Precedent carte</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <source>Ctrl+PageDown</source>
        <translation>Ctrl+PageDown</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Ctrl+PageUp</source>
        <translation>Ctrl+PageUp</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>Ctrl+Number</source>
        <translation>Ctrl+Numeró</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="98"/>
        <location filename="../shortcuts.ui" line="106"/>
        <source>Jump to tab</source>
        <translation>Ear a un carte</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="103"/>
        <source>Alt+Number</source>
        <translation>Alt+Numeró</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="111"/>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="114"/>
        <source>Go up</source>
        <translation>Al superiori</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="119"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="122"/>
        <source>Search dialog</source>
        <translation>Dialog de sercha</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="127"/>
        <source>Shift+Insert</source>
        <translation>Shift+Insert</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="130"/>
        <source>Paste into transient filter bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="135"/>
        <source>Drop+Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="143"/>
        <source>Drop+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="151"/>
        <source>Drop+Shift+Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="138"/>
        <source>Move file on dropping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="146"/>
        <source>Copy file on dropping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="154"/>
        <source>Make a symlink on dropping</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>Gerente de files</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="81"/>
        <source>Recent F&amp;iles</source>
        <translation>Recent f&amp;iles</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="143"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="150"/>
        <source>Path &amp;Bar</source>
        <translation>&amp;Barra de fólderes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="157"/>
        <source>&amp;Filtering</source>
        <translation>&amp;Filtres</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="232"/>
        <source>&amp;Tools</source>
        <translation>U&amp;tensiles</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="291"/>
        <source>Go &amp;Up</source>
        <translation>Al s&amp;uperiori</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="294"/>
        <source>Go Up</source>
        <translation>Al superiori</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="297"/>
        <source>Alt+Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="306"/>
        <source>&amp;Home</source>
        <translation>&amp;Hem</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="309"/>
        <source>Alt+Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="318"/>
        <source>&amp;Reload</source>
        <translation>&amp;Recargar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="321"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="330"/>
        <source>Go</source>
        <translation>Ear</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="339"/>
        <source>Quit</source>
        <translation>Surtir</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="348"/>
        <source>&amp;About</source>
        <translation>&amp;Pri</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="357"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nov fenestre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="360"/>
        <source>New Window</source>
        <translation>Nov fenestre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="363"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="371"/>
        <source>Show &amp;Hidden</source>
        <translation>Revelar &amp;celat</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="374"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="383"/>
        <source>&amp;Computer</source>
        <translation>&amp;Computator</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="392"/>
        <source>&amp;Trash</source>
        <translation>&amp;Paper-corb</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="397"/>
        <source>&amp;Network</source>
        <translation>&amp;Rete</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="406"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Pupitre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="415"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>M&amp;arcar li págine</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="420"/>
        <source>&amp;Applications</source>
        <translation>&amp;Applicationes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="425"/>
        <source>Reload</source>
        <translation>Recargar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="433"/>
        <source>&amp;Icon View</source>
        <translation>Vise de &amp;icones</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="441"/>
        <source>&amp;Compact View</source>
        <translation>Vise &amp;compact</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="449"/>
        <source>&amp;Detailed List</source>
        <translation>Liste &amp;detalliat</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="457"/>
        <source>&amp;Thumbnail View</source>
        <translation>Vise de minia&amp;turas</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="466"/>
        <source>Cu&amp;t</source>
        <translation>E&amp;xciser</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="469"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="478"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="481"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="490"/>
        <source>&amp;Paste</source>
        <translation>Coll&amp;ar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="493"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="502"/>
        <source>Select &amp;All</source>
        <translation>Selecter &amp;omni</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="505"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="510"/>
        <source>De&amp;select All</source>
        <translation>De&amp;select omni</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="513"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="518"/>
        <source>Pr&amp;eferences</source>
        <translation>Pr&amp;eferenties</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="526"/>
        <source>&amp;Ascending</source>
        <translation>Secun &amp;ascension</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="538"/>
        <source>&amp;Descending</source>
        <translation>Secun &amp;descension</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="550"/>
        <source>&amp;By File Name</source>
        <translation>Sec&amp;un nómine</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="558"/>
        <source>By &amp;Modification Time</source>
        <translation>Secun &amp;modification</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="566"/>
        <source>By C&amp;reation Time</source>
        <translation>Secun c&amp;reation</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="574"/>
        <source>By Deletio&amp;n Time</source>
        <translation>Secun r&amp;emotion</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="582"/>
        <source>By File &amp;Type</source>
        <translation>Secun li &amp;tip de file</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="590"/>
        <source>By &amp;Owner</source>
        <translation>Secun p&amp;ossessor</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="598"/>
        <source>By &amp;Group</source>
        <translation>Secun &amp;gruppe</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="606"/>
        <source>&amp;Folder First</source>
        <translation>&amp;Fólderes in li inicie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="614"/>
        <source>&amp;Hidden Last</source>
        <translation>C&amp;elat in li fin</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="927"/>
        <source>Shift+F2</source>
        <translation>Shift+F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1015"/>
        <source>Preserve Settings Recursively from &amp;Here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1020"/>
        <source>&amp;Go to Source of Inherited Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1025"/>
        <source>&amp;Remove Settings of Nonexistent Folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1033"/>
        <source>&amp;Clear</source>
        <translation>&amp;Vacuar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="667"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="728"/>
        <source>&amp;Case Sensitive</source>
        <translation>&amp;Atenter a min/MAJ</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="736"/>
        <source>By File &amp;Size</source>
        <translation>Secun &amp;grandore</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="745"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Cluder li fenestre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="748"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="770"/>
        <source>Open Tab in &amp;Root Instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="784"/>
        <source>&amp;Folder</source>
        <translation>&amp;Fólder</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="796"/>
        <source>&amp;Blank File</source>
        <translation>Un &amp;blanc file</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="887"/>
        <source>Preserve Settings for &amp;This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="932"/>
        <source>&amp;Show/Focus Filter Bar</source>
        <translation>Al panel de fi&amp;ltre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="935"/>
        <source>Show Filter Bar</source>
        <translation>Monstrar li filtre</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="938"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="946"/>
        <source>S&amp;plit View</source>
        <translation>Fe&amp;nder li vise</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="949"/>
        <source>Split View</source>
        <translation>Fender li vise</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="952"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="957"/>
        <source>&amp;Copy Full Path</source>
        <translation>&amp;Copiar li complet rute</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="964"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="975"/>
        <source>Show Thumb&amp;nails</source>
        <translation>Mo&amp;nstrar miniaturas</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="978"/>
        <source>Show Thumbnails</source>
        <translation>Monstrar miniaturas</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="986"/>
        <source>S&amp;ide Pane</source>
        <translation>Panel &amp;lateral</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="989"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="994"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="999"/>
        <source>Open Tab in &amp;Admin Mode</source>
        <translation>&amp;Aperter un carte quam li superusator</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="1004"/>
        <location filename="../main-win.ui" line="1007"/>
        <source>Create Launcher</source>
        <translation>Crear un lansator</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="822"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="827"/>
        <source>&amp;Clear All Filters</source>
        <translation>Va&amp;cuar omni filtres</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="830"/>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="839"/>
        <source>Close &amp;previous tabs</source>
        <translation>Cluder li &amp;precedent cartes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="848"/>
        <source>Close &amp;next tabs</source>
        <translation>Cluder li s&amp;equent cartes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="896"/>
        <source>Connect to &amp;Server</source>
        <translation>Conexer a un &amp;servitor</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="904"/>
        <source>&amp;Location</source>
        <translation>&amp;Localisation</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="912"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="917"/>
        <source>&amp;Bulk Rename</source>
        <translation>Renomination in &amp;masse</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="924"/>
        <source>Bulk Rename</source>
        <translation>Renomination in masse</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="853"/>
        <source>Close &amp;other tabs</source>
        <translation>Cluder li &amp;altri cartes</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="819"/>
        <source>Permanent &amp;filter bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="861"/>
        <source>&amp;Menu bar</source>
        <translation>Barra de &amp;menú</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="864"/>
        <source>Menu bar</source>
        <translation>Barra de menú</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="867"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="876"/>
        <location filename="../main-win.ui" line="879"/>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="623"/>
        <source>New &amp;Tab</source>
        <translation>Nov &amp;carte</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="164"/>
        <source>&amp;Customized View Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="626"/>
        <source>New Tab</source>
        <translation>Nov carte</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="629"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="638"/>
        <source>Go &amp;Back</source>
        <translation>Ear &amp;retro</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="641"/>
        <source>Go Back</source>
        <translation>Ear retro</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="644"/>
        <source>Alt+Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="653"/>
        <source>Go &amp;Forward</source>
        <translation>Ear ad a&amp;van</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="656"/>
        <source>Go Forward</source>
        <translation>Ear ad avan</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="659"/>
        <source>Alt+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="664"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Inverter li selection</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="676"/>
        <source>&amp;Delete</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="679"/>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="684"/>
        <source>&amp;Rename</source>
        <translation>Re&amp;nominar</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="691"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="700"/>
        <source>C&amp;lose Tab</source>
        <translation>C&amp;luder li carte</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="703"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="712"/>
        <source>File &amp;Properties</source>
        <translation>&amp;Proprietás de file</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="715"/>
        <source>Alt+Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="720"/>
        <source>&amp;Folder Properties</source>
        <translation>Proprietás de &amp;fólder</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="753"/>
        <source>Edit Bookmarks</source>
        <translation>Redacter marca-págines</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="762"/>
        <source>Open &amp;Terminal</source>
        <translation>Aperter li &amp;terminal</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="765"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="775"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>R&amp;edacter marca-págines</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="787"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="799"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="804"/>
        <source>&amp;Find Files</source>
        <translation>Trovar &amp;files</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="811"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="70"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="74"/>
        <source>C&amp;reate New</source>
        <translation>C&amp;rear un nov</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="102"/>
        <source>&amp;Help</source>
        <translation>Au&amp;xilie</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="109"/>
        <location filename="../main-win.ui" line="133"/>
        <source>&amp;View</source>
        <translation>&amp;Vise</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="113"/>
        <source>&amp;Sorting</source>
        <translation>Ór&amp;dine</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="189"/>
        <source>&amp;Edit</source>
        <translation>R&amp;edacter</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="208"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Marca-págines</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="215"/>
        <source>&amp;Go</source>
        <translation>&amp;Ear</translation>
    </message>
    <message>
        <location filename="../main-win.ui" line="257"/>
        <source>Main Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>Name of configuration profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="189"/>
        <source>PROFILE</source>
        <translation>PROFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="192"/>
        <source>Run PCManFM-Qt as a daemon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="195"/>
        <source>Quit PCManFM-Qt</source>
        <translation>Surtir de PCManFM-Qt</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="198"/>
        <source>Launch desktop manager</source>
        <translation>Gerer li Pupitre</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="201"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Desactivar li gerente del Pupitre</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="204"/>
        <location filename="../application.cpp" line="219"/>
        <source>NAME</source>
        <translation>NÓMINE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="207"/>
        <source>Open new window</source>
        <translation>Aperter un nov fenestre</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="210"/>
        <source>Open Find Files utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Assignar li FILE quam li tapete</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="213"/>
        <source>FILE</source>
        <translation>FILE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>MODE</source>
        <translation>MODE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="216"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="219"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="222"/>
        <source>Files or directories to open</source>
        <translation>Files o fólders por aperter</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="222"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="660"/>
        <location filename="../application.cpp" line="665"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="665"/>
        <source>Terminal emulator is not set.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="44"/>
        <source>Open in file manager</source>
        <translation>Aperter in li Gerente de files</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="137"/>
        <source>Removable Disk</source>
        <translation>Removabil disco</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation>SSH</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation>WebDav</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation>WebDav secur</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation>HTTPS</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopEntryDialog</name>
    <message>
        <location filename="../desktopentrydialog.cpp" line="35"/>
        <source>Command:</source>
        <translation>Comande:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="36"/>
        <source>The command to execute.</source>
        <translation>Li comande a executer.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="39"/>
        <source>URL:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="40"/>
        <source>The URL to access.</source>
        <translation>Li adresse a aperter.</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="67"/>
        <source>Select an icon</source>
        <translation>Selecter un icone</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="69"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Images (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="91"/>
        <source>Select an executable file</source>
        <translation>Selecter un executibil file</translation>
    </message>
    <message>
        <location filename="../desktopentrydialog.cpp" line="99"/>
        <source>Select a file</source>
        <translation>Selecter un file</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="55"/>
        <source>Fill with background color only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="56"/>
        <source>Stretch to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="57"/>
        <source>Stretch to fit the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="58"/>
        <source>Center on the screen</source>
        <translation>Centrar sur li ecran</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="59"/>
        <source>Tile the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="60"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="272"/>
        <source>Select Wallpaper</source>
        <translation>Selecter un tapete</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="276"/>
        <source>Image Files</source>
        <translation>Files de image</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="318"/>
        <source>Select Wallpaper Folder</source>
        <translation>Selecter un fólder de tapetes</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="333"/>
        <source>Trash (One item)</source>
        <translation>Paper-corb (1 element)</translation>
    </message>
    <message numerus="yes">
        <location filename="../desktopwindow.cpp" line="336"/>
        <source>Trash (%Ln items)</source>
        <translation>
            <numerusform>Paper-corb (%Ln element)</numerusform>
            <numerusform>Paper-corb (%Ln elementes)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="340"/>
        <source>Trash (Empty)</source>
        <translation>Paper-corb (vacui)</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="375"/>
        <source>Computer</source>
        <translation>Computator</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="389"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1052"/>
        <source>Open</source>
        <translation>Aperter</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1058"/>
        <location filename="../desktopwindow.cpp" line="1098"/>
        <source>Stic&amp;k to Current Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1066"/>
        <source>Empty Trash</source>
        <translation>Vacuar li Paper-corb</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1132"/>
        <source>Hide Desktop Items</source>
        <translation>Celar elementes del Pupitre</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1138"/>
        <source>Create Launcher</source>
        <translation>Crear un lansator</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="1141"/>
        <source>Desktop Preferences</source>
        <translation>Preferenties del Pupitre</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterBar</name>
    <message>
        <location filename="../tabpage.cpp" line="95"/>
        <source>Filter:</source>
        <translation>Filtre:</translation>
    </message>
</context>
<context>
    <name>PCManFM::FilterEdit</name>
    <message>
        <location filename="../tabpage.cpp" line="65"/>
        <source>Clear text (Ctrl+K or Esc)</source>
        <translation>Vacuar li textu (Ctrl+K o Esc)</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Root Instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <source>Hide menu bar</source>
        <translation>Celar li panel de menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1224"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2193"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mover al Paper-corb</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <location filename="../mainwindow.cpp" line="2193"/>
        <source>&amp;Delete</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2029"/>
        <source>Customized View Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2300"/>
        <location filename="../mainwindow.cpp" line="2308"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2308"/>
        <source>Switch user command is not set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Cleaning Folder Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2400"/>
        <source>Do you want to remove settings of nonexistent folders?
They might be useful if those folders are created again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Icon View</source>
        <translation>Vise de icones</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Compact View</source>
        <translation>Vise compact</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Thumbnail View</source>
        <translation>Vise de miniaturas</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="218"/>
        <source>Detailed List View</source>
        <translation>Vise de detalliat liste</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="311"/>
        <source>Remove if added by user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="335"/>
        <source>Open user-defined list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="452"/>
        <source>Search Results</source>
        <translation>Resultates de sercha</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="455"/>
        <source>Applications</source>
        <translation>Applicationes</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="459"/>
        <source>Computer</source>
        <translation>Computator</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="462"/>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="465"/>
        <source>Trash</source>
        <translation>Paper-corb</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="471"/>
        <source>Desktop</source>
        <translation>Pupitre</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="562"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="571"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Líber spacie: %1 (%2 total)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="588"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n element</numerusform>
            <numerusform>%n elementes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="590"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform> (%n celat)</numerusform>
            <numerusform> (%n celat)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="595"/>
        <location filename="../tabpage.cpp" line="796"/>
        <location filename="../tabpage.cpp" line="810"/>
        <source>Link to</source>
        <translation>Ligament a</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="822"/>
        <source>%n item(s) selected</source>
        <translation>
            <numerusform>%n element selectet</numerusform>
            <numerusform>%n elementes selectet</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="59"/>
        <source>Many files</source>
        <translation>Multiplic files</translation>
    </message>
    <message numerus="yes">
        <location filename="../view.cpp" line="60"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Esque vu vole aperter %1 file?</numerusform>
            <numerusform>Esque vu vole aperter ti %1 files?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../view.cpp" line="133"/>
        <source>Open in New T&amp;ab</source>
        <translation>Aperter in un nov c&amp;arte</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="137"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Aperter in un nov fene&amp;stre</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="145"/>
        <location filename="../view.cpp" line="174"/>
        <source>Open in Termina&amp;l</source>
        <translation>Aperter in li termina&amp;l</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="160"/>
        <source>Show in New T&amp;ab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../view.cpp" line="164"/>
        <source>Show in New Win&amp;dow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferenties</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>Interfacie de usator</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>Conduida</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="50"/>
        <location filename="../preferences.ui" line="642"/>
        <source>Thumbnail</source>
        <translation>Minuatura</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>Avansat</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="222"/>
        <source>Select newly created files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="296"/>
        <source>Icons</source>
        <translation>Icones</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="328"/>
        <source>Size of big icons:</source>
        <translation>Grandore de grand icones:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="345"/>
        <source>Size of small icons:</source>
        <translation>Grandore de micri icones:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="362"/>
        <source>Size of thumbnails:</source>
        <translation>Dimension de miniaturas:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="376"/>
        <source>Size of side pane icons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="308"/>
        <source>Icon theme:</source>
        <translation>Tema de icones:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="546"/>
        <source>Window</source>
        <translation>Fenestre</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="559"/>
        <source>Always show the tab bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="566"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Monstrar li buton «Cluder» sur cartes\t	</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="580"/>
        <source>Remember the size of the last closed window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="587"/>
        <source>Default width of new windows:</source>
        <translation>Largore predefinit por nov fenestres:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="601"/>
        <source>Default height of new windows:</source>
        <translation>Altore predefinit por nov fenestres:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="93"/>
        <source>Open files with single click</source>
        <translation>Aperter files per un singul clic</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="162"/>
        <source>Default view mode:</source>
        <translation>Vise predefinit:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="119"/>
        <source> sec</source>
        <translation> sec</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="175"/>
        <source>File Operations</source>
        <translation>Operationes con files</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="181"/>
        <source>Confirm before deleting files</source>
        <translation>Confirmar li deletion de files</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="188"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="651"/>
        <source>Show thumbnails of files</source>
        <translation>Monstrar miniaturas de files</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="658"/>
        <source>Only show thumbnails for local files</source>
        <translation>Monstrar miniaturas solmen por local files</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="40"/>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="90"/>
        <source>If this is unchecked, the DE setting will be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="103"/>
        <location filename="../preferences.ui" line="116"/>
        <source>Set to zero to disable auto-selection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="106"/>
        <source>Delay of auto-selection in single click mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="144"/>
        <source>Open in current tab</source>
        <translation>Aperter in li actual carte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="149"/>
        <source>Open in new tab</source>
        <translation>Aperter in un nov carte</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="154"/>
        <source>Open in new window</source>
        <translation>Aperter in un nov fenestre</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="195"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="202"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="209"/>
        <location filename="../preferences.ui" line="409"/>
        <location filename="../preferences.ui" line="419"/>
        <source>Requires application restart to take effect completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="212"/>
        <source>Launch executable files without prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="219"/>
        <source>Renamed files will also be selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="244"/>
        <source>Number of recent files:</source>
        <translation>Númere de recent files:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="325"/>
        <location filename="../preferences.ui" line="335"/>
        <source>Used by Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="342"/>
        <location filename="../preferences.ui" line="352"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="359"/>
        <location filename="../preferences.ui" line="369"/>
        <source>Used by Thumbnail View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="389"/>
        <source>User interface</source>
        <translation>Interfacie de usator</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="402"/>
        <source>Treat backup files as hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="422"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Ínclar icones por celat files</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="459"/>
        <source>Minimum item margins in icon view:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="466"/>
        <source>3 px by default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="469"/>
        <location filename="../preferences.ui" line="493"/>
        <source> px</source>
        <translation type="unfinished"> pix</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="482"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="489"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="506"/>
        <source>Lock</source>
        <translation>Serrar</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="555"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="573"/>
        <source>Switch to newly opened tab</source>
        <translation>Selecter apert cartes</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="615"/>
        <source>Reopen last window tabs in a new window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="665"/>
        <location filename="../preferences.ui" line="677"/>
        <source>The built-in thumbnailer makes thumbnails of images that are supported by Qt.

Usually, most image types are supported. The default size limit is 4 MiB.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="670"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>Max grandore por li intern creator de miniaturas:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="682"/>
        <location filename="../preferences.ui" line="718"/>
        <source> MiB</source>
        <translation> Mio</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="698"/>
        <location filename="../preferences.ui" line="710"/>
        <source>If existing, external thumbnailers are used for videos, PDF documents, etc.

A value of -1 means that there is no limit for the file size (the default).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="703"/>
        <source>File size limit for external thumbnailers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="715"/>
        <source>No limit</source>
        <translation>Sin límite</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="833"/>
        <source>Terminal emulator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="842"/>
        <source>Command:</source>
        <translation type="unfinished">Comande:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="849"/>
        <source>Example: qterminal
It is the name of the executable file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="860"/>
        <source>Execution option:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="867"/>
        <source>Example: -e
It can be left empty if the terminal is already supported
or does not have such an option; required otherwise.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="879"/>
        <source>Custom option(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="886"/>
        <source>This is optional, depends on the terminal,
and can be any group of custom options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="964"/>
        <source>Search</source>
        <translation>Sercha</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="979"/>
        <source>Maximum search history:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="993"/>
        <source>Clear search history</source>
        <translation>Vacuar li diarium de sercha</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="1028"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="136"/>
        <source>Bookmarks menu:</source>
        <translation>Menú de marca-págines:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="129"/>
        <source>Show folder context menu with Ctrl + right click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="229"/>
        <source>Open folders in new tabs as far as possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="232"/>
        <source>Single window mode</source>
        <translation>Mode de singul fenestre</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="412"/>
        <source>Always show real file names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="429"/>
        <source>Do not show file tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="436"/>
        <source>Disable smooth scrolling</source>
        <translation>Desactivar glittat rulament</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="648"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>Besona ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="754"/>
        <source>Auto Mount</source>
        <translation>Monter automaticmen</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="760"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="767"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="774"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="784"/>
        <source>When removable medium unmounted:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="790"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="797"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="824"/>
        <source>Programs</source>
        <translation>Programmas</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="900"/>
        <source>Switch &amp;user command:</source>
        <translation>Comande a cambiar li &amp;usator:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="910"/>
        <source>Example:
lxsudo dbus-run-session -- %s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="918"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>In&amp;tegration del archivator:</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="934"/>
        <source>Templates</source>
        <translation>Modelles</translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="940"/>
        <source>Show only user defined templates in menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="947"/>
        <source>Show only one template for each MIME type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="954"/>
        <source>Run default application after creation from template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferences.ui" line="395"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bulkrename.cpp" line="185"/>
        <location filename="../bulkrename.cpp" line="247"/>
        <location filename="../bulkrename.cpp" line="288"/>
        <source>Renaming files...</source>
        <translation>Renominante files...</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="185"/>
        <location filename="../bulkrename.cpp" line="247"/>
        <location filename="../bulkrename.cpp" line="288"/>
        <source>Abort</source>
        <translation>Interrupter</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="194"/>
        <location filename="../bulkrename.cpp" line="254"/>
        <location filename="../bulkrename.cpp" line="295"/>
        <source>Warning</source>
        <translation>Avise</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="194"/>
        <location filename="../bulkrename.cpp" line="254"/>
        <location filename="../bulkrename.cpp" line="295"/>
        <source>Renaming is aborted.</source>
        <translation>Renomination sta anullat.</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="220"/>
        <location filename="../bulkrename.cpp" line="224"/>
        <location filename="../bulkrename.cpp" line="234"/>
        <location filename="../bulkrename.cpp" line="243"/>
        <location filename="../bulkrename.cpp" line="277"/>
        <location filename="../bulkrename.cpp" line="281"/>
        <location filename="../bulkrename.cpp" line="318"/>
        <location filename="../bulkrename.cpp" line="322"/>
        <location filename="../tabpage.cpp" line="1149"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="220"/>
        <location filename="../bulkrename.cpp" line="277"/>
        <location filename="../bulkrename.cpp" line="318"/>
        <source>No file could be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="224"/>
        <location filename="../bulkrename.cpp" line="281"/>
        <location filename="../bulkrename.cpp" line="322"/>
        <source>Some files could not be renamed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="234"/>
        <source>Nothing to find.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../bulkrename.cpp" line="243"/>
        <source>Invalid regular expression.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="1149"/>
        <source>Cannot open as Admin.</source>
        <translation>Ne successat aperter quam li superusator.</translation>
    </message>
</context>
</TS>
